[Koha-patches] [PATCH] Bug 6716: Update documentation for the letter table

Nicole C. Engard nengard at bywatersolutions.com
Thu Jul 19 03:59:30 CEST 2012


The letter table is now for slips and notices, and
had other changes necessary.
---
 installer/data/mysql/kohastructure.sql |   12 ++++++------
 1 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/installer/data/mysql/kohastructure.sql b/installer/data/mysql/kohastructure.sql
index 3b9827a..967739b 100644
--- a/installer/data/mysql/kohastructure.sql
+++ b/installer/data/mysql/kohastructure.sql
@@ -1179,13 +1179,13 @@ CREATE TABLE `creator_templates` (
 
 DROP TABLE IF EXISTS `letter`;
 CREATE TABLE `letter` ( -- table for all notice templates in Koha
-  `module` varchar(20) NOT NULL default '', -- Koha module that triggers this notice
-  `code` varchar(20) NOT NULL default '', -- unique identifier for this notice
-  `branchcode` varchar(10) default NULL, -- foreign key, linking to the branches table for the location the item was checked out
-  `name` varchar(100) NOT NULL default '', -- plain text name for this notice
-  `is_html` tinyint(1) default 0,
+  `module` varchar(20) NOT NULL default '', -- Koha module that triggers this notice or slip
+  `code` varchar(20) NOT NULL default '', -- unique identifier for this notice or slip
+  `branchcode` varchar(10) default NULL, -- the branch this notice or slip is used at (branches.branchcode)
+  `name` varchar(100) NOT NULL default '', -- plain text name for this notice or slip
+  `is_html` tinyint(1) default 0, -- does this notice or slip use HTML (1 for yes, 0 for no)
   `title` varchar(200) NOT NULL default '', -- subject line of the notice
-  `content` text, -- body text for the notice
+  `content` text, -- body text for the notice or slip
   PRIMARY KEY  (`module`,`code`, `branchcode`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 
-- 
1.7.2.3



More information about the Koha-patches mailing list